package com.ruoyi.basetyre.service.impl;

import java.util.List;
import java.util.UUID;

import com.ruoyi.common.core.domain.model.LoginUser;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.basetyre.mapper.BaseDeviceMapper;
import com.ruoyi.basetyre.domain.BaseDevice;
import com.ruoyi.basetyre.service.IBaseDeviceService;

/**
 * 设备管理Service业务层处理
 * 
 * @author Yangwl
 * @date 2023-02-09
 */
@Service
public class BaseDeviceServiceImpl implements IBaseDeviceService 
{
    @Autowired
    private BaseDeviceMapper baseDeviceMapper;

    /**
     * 查询设备管理
     * 
     * @param id 设备管理主键
     * @return 设备管理
     */
    @Override
    public BaseDevice selectBaseDeviceById(String id)
    {
        return baseDeviceMapper.selectBaseDeviceById(id);
    }

    /**
     * 查询设备管理列表
     * 
     * @param baseDevice 设备管理
     * @return 设备管理
     */
    @Override
    public List<BaseDevice> selectBaseDeviceList(BaseDevice baseDevice)
    {
        return baseDeviceMapper.selectBaseDeviceList(baseDevice);
    }

    /**
     * 新增设备管理
     * 
     * @param baseDevice 设备管理
     * @return 结果
     */
    @Override
    public int insertBaseDevice(BaseDevice baseDevice)
    {
        baseDevice.setCreateTime(DateUtils.getNowDate());
        baseDevice.setId(UUID.randomUUID().toString());
        LoginUser loginUser= SecurityUtils.getLoginUser();
        baseDevice.setCreateBy(loginUser.getUserId().toString());
        baseDevice.setCreateName(loginUser.getUsername());
        baseDevice.setModifyBy(loginUser.getUserId().toString());
        baseDevice.setModifyTime(DateUtils.getNowDate());
        return baseDeviceMapper.insertBaseDevice(baseDevice);
    }

    /**
     * 修改设备管理
     * 
     * @param baseDevice 设备管理
     * @return 结果
     */
    @Override
    public int updateBaseDevice(BaseDevice baseDevice)
    {
        return baseDeviceMapper.updateBaseDevice(baseDevice);
    }

    /**
     * 批量删除设备管理
     * 
     * @param ids 需要删除的设备管理主键
     * @return 结果
     */
    @Override
    public int deleteBaseDeviceByIds(String[] ids)
    {
        return baseDeviceMapper.deleteBaseDeviceByIds(ids);
    }

    /**
     * 删除设备管理信息
     * 
     * @param id 设备管理主键
     * @return 结果
     */
    @Override
    public int deleteBaseDeviceById(String id)
    {
        return baseDeviceMapper.deleteBaseDeviceById(id);
    }
}
